@@ -2,6 +2,8 @@
 
 """Validate instance using Himarc JSON schema"""
 
+from __future__ import annotations
+
 import json
 import os
 from collections.abc import Iterable
@@ -13,14 +15,20 @@ from jsonschema.exceptions import ValidationError
 __all__ = ["validate_himarc", "get_himarc_validation_errors"]
 
 
-SCHEMA_DIR = os.path.join(os.path.dirname(os.path.abspath(__file__)), "schema")
-SCHEMA_FILENAME = "himarc.schema.json"
-
-
-def _get_schema() -> Dict[str, Any]:
+def _get_schema(category="register") -> Dict[str, Any]:
     """Get Himarc JSON schema data."""
-    path = os.path.join(SCHEMA_DIR, SCHEMA_FILENAME)
-    with open(path, "r") as json_schema_file:
+    schema_available = ["register", "work"]
+    schema_filename = f"himarc-{category}.schema.json"
+    if category not in schema_available:
+        raise ValueError(
+            f"Invalid schema category must be : [{', '.join(schema_available)}]"  # noqa: E501
+        )
+
+    schema_dir = os.path.join(
+        os.path.dirname(os.path.abspath(__file__)), "schema"
+    )
+    path_schema = os.path.join(schema_dir, schema_filename)
+    with open(path_schema, "r") as json_schema_file:
         return json.load(json_schema_file)
 
 
